@@ -17,7 +17,7 @@ p_value.flexsurvreg <- function(model, ...) {
   params <- insight::get_parameters(model)
   est <- params$Estimate
   se <- standard_error(model)$SE
-  p <- 2 * stats::pt(abs(est / se), df = degrees_of_freedom(model, method = "any"), lower.tail = FALSE)
+  p <- 2 * stats::pt(abs(est / se), df = insight::get_df(x = model, type = "wald"), lower.tail = FALSE)
   .data_frame(
     Parameter = params$Parameter,
     p = as.vector(p)
