@@ -2,7 +2,7 @@ skip_if_not_installed("withr")
 
 # make sure we have the correct interaction mark for tests
 withr::with_options(
-  list(parameters_interaction = "*"),
+  list(parameters_interaction = "*", easystats_table_width = Inf),
   {
     data(iris)
     m1 <- lm(Sepal.Length ~ Species, data = iris)
@@ -122,6 +122,8 @@ withr::with_options(
 
     test_that("compare_parameters, print_md", {
       skip_if_not_installed("lme4")
+      skip_if_not_installed("knitr")
+
       data(sleepstudy, package = "lme4")
       set.seed(1234)
       sleepstudy$grp <- as.factor(sample.int(3, nrow(sleepstudy), replace = TRUE))
