@@ -51,7 +51,7 @@ test_that("predictions()", {
   expect_identical(nrow(out), 3L)
   expect_named(out, c(
     "Predicted", "Species", "SE", "CI", "CI_low", "CI_high", "S", "Statistic",
-    "p"
+    "df", "p"
   ))
   out <- model_parameters(p, exponentiate = TRUE)
   expect_equal(out$Predicted, c(30.81495, 15.95863, 19.57004), tolerance = 1e-4)
